/** \file TocAccountIntermediateWidget.h
 * \brief Declaration of TocAccountIntermediateWidget class
 * 
 * TOQ - Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef TOCACCOUNTINTERMEDIATEWIDGET_H
#define TOCACCOUNTINTERMEDIATEWIDGET_H

#include <QWidget>

class QPushButton;
class QFrame;

QT_BEGIN_NAMESPACE

/** \brief TocAccountIntermediateWidget class
 * 
 * Window to select account settings mode. 
 */
class TocAccountIntermediateWidget : public QWidget
{
	Q_OBJECT

public:

	/**
	 * Public Constructor
	 * 
	 * @param create Indicates if widget shoulb be in `Create mode`
	 */
	TocAccountIntermediateWidget( QWidget * parent = 0, Qt::WindowFlags flags = 0 );

	/**
	 * Destructor
	 */
	~TocAccountIntermediateWidget();

	/** \brief Allows enabling/disabling FTU mode during runtime
	 * 
	 * Method for switching `FTU mode` on and off
	 * 
	 * @param bool ftu Indicates if widget should enter FTU mode
	 */
	void enableFTUMode( bool ftu );

signals:

	/** \brief Emited when user clicks createButton
	 * 
	 */
	void createClicked();

	/** \brief Emited when user clicks createButton
	 * 
	 */
	void editClicked();

	/** \brief Emited when user clicks backButton
	 * 
	 */
	void backClicked();

private: // Methods

	/** \brief Sets style sheets for each widget
	 * 
	 * Used to overload style sheet properties that could come from main style sheet,
	 * to forbid corruption of the application layout from the external style sheets. 
	 */
	void setupStyles();

private: // Members

	QPushButton*		_pBackButton;			/// Create Account Settings button
	QPushButton*		_pCreateButton;			/// Create Account Settings button
	QPushButton*		_pEditButton;			/// Edit Account Settings button
	QFrame*			_pIntermediateFrame;		/// Background frame of window
};

QT_END_NAMESPACE

#endif // TOCACCOUNTINTERMEDIATEWIDGET_H
