/** \file TocEmoticonsDialog.h
 * \brief Declaration of TocEmoticonsDialog class
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef TOCEMOTICONSDIALOG_H
#define TOCEMOTICONSDIALOG_H

#include <QDialog>

QT_BEGIN_NAMESPACE

class Ui_TocEmoticonsDialogClass;
class QListWidgetItem;

class TocEmoticonsDialog : public QDialog
{
    Q_OBJECT

public:
	   
	/** \brief Static public constructor
	 * 
	 * @param parent Emoticons dialog parent widget for application style inheretance.
	 * 
	 * @return Pointer to the static instance
	 */
	
	static TocEmoticonsDialog* getInstance(QWidget* parent);
	
	/** \brief Emoticon alias method.
	 * 
	 * @return String alias for the selected emoticon.
	 */	
	QString getSelectedEmoticonAlias();
	
private:
	
	/**
	 * Private Constructor
	 */	
    TocEmoticonsDialog(QWidget *parent = 0);
    
	/**
	 * Destructor
	 */
    ~TocEmoticonsDialog();	
	
private slots:

	/** \brief Emoticon selected slot
	*
	* Invoked when user selects an emoticon from the emoticons dialog window.
	*
	* @param pItem Selected emoticon from the list. 
	*   
	*/
	void onEmoticonSelected(QListWidgetItem* pItem);
	
private:
	
	static TocEmoticonsDialog* _pSelf;	/// Static pointer to TocEmoticonDialog class.
	
	QString _selectedEmoticonAlias;		/// Selected emoticon string alias.
	
    Ui_TocEmoticonsDialogClass* ui;		/// Pointer to the TocEmoticonsDialogClass form.
};

QT_END_NAMESPACE

#endif // TOCEMOTICONSDIALOG_H
