/** \file TocGeneralSettingsWidget.h
 * \brief Declaration of TocGeneralSettingsWidget class
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef TOCGENERALSETTINGSWIDGET_H
#define TOCGENERALSETTINGSWIDGET_H

#include <QWidget>
#include "defs.h"

class Ui_TocGeneralSettingsWidgetClass;

QT_BEGIN_NAMESPACE

/** \brief TocGeneralSettingsWidget class
 * 
 * Configuration window for general application settings. 
 */
class TocGeneralSettingsWidget : public QWidget
{
	Q_OBJECT

public:

	/**
	 * Public Constructor
	 */
	TocGeneralSettingsWidget( QWidget * parent = 0, Qt::WindowFlags flags = 0 );

	/**
	 * Destructor
	 */
	~TocGeneralSettingsWidget();

signals:

	/** \brief Signal connected to returnToContacts() slot in TocMainWindow
	 * 
 	 */
	void finished();

	/** \brief Signal connected to returnToSettings() slot in TocMainWindow
	 * 
 	 */
	void backClicked();

private slots:

	/** \brief Used to save general settings
	 * 
	 * This slot is used when user clicks on the Ok button.
	 * Information in UI are saved into TocSettings 
	 */
	void saveGeneralSettings();

private: // Members

	Ui_TocGeneralSettingsWidgetClass* ui; 			/// Ui definition header
};

QT_END_NAMESPACE

#endif // TOCGENERALSETTINGSWIDGET_H
