/** \file TocSettingsWidget.h
 * \brief Declaration of TocSettingsWidget class
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef TOCSETTINGSWIDGET_H
#define TOCSETTINGSWIDGET_H

#include <QWidget>
#include "defs.h"

class QSignalMapper;
class QPushButton;
class QFrame;

QT_BEGIN_NAMESPACE

/** \brief TocSettingsWidget class
 * 
 * Widged used to display available configuration windows and
 * to choose between them.
 */
class TocSettingsWidget : public QWidget
{
	Q_OBJECT

public:

	/**
	 * Public Constructor
	 */
	TocSettingsWidget( QWidget * parent = 0, Qt::WindowFlags flags = 0 );

	/**
	 * Destructor
	 */
	~TocSettingsWidget();

signals:

	/** \brief Emited when user selects settings subsection
	 * 
	 * ViewType is casted to int because TocSettingsWidget
	 * uses a QSignalMapper for convenience.
	 * 
	 * @param viewType ViewType casted to int of the selected settings
	 */
	void triggered(/*ViewType*/int viewType);

private: // Methods

	/** \brief Sets style sheets for each widget
	 * 
	 * Used to overload style sheet properties that could come from main style sheet,
	 * to forbid corruption of the application layout from the external style sheets. 
	 */
	void setupStyles();

private: // Members

	QSignalMapper*				signalMapper;	/// QSignalMapper used for convenience
	QPushButton*				generalButton;	/// General Settings button
	QPushButton*				accountButton;	/// Account Settings button
	QPushButton*				backButton;		/// Back button
	QPushButton*				themesButton;	/// Themes Settings button
	QFrame*						settingsFrame;	/// Background frame of window
};

QT_END_NAMESPACE

#endif // TOCSETTINGSWIDGET_H
