/** \file TocThemesSettingsWidget.h
 * \brief Declaration of TocThemesSettingsWidget class
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef TOCTHEMESSETTINGSWIDGET_H
#define TOCTHEMESSETTINGSWIDGET_H

#include "defs.h"

#include <QtGui/QWidget>

class Ui_TocThemesSettingsWidgetClass;

class QShowEvent;

QT_BEGIN_NAMESPACE

/** \brief TocThemesSettingsWidget class
 * 
 * Configuration window for application themes settings. 
 */
class TocThemesSettingsWidget : public QWidget
{
	Q_OBJECT

public:

	/**
	 * Public Constructor
	 */
	TocThemesSettingsWidget(QWidget* parent = 0, Qt::WindowFlags flags = 0);

	/**
	 * Destructor
	 */
	~TocThemesSettingsWidget();

signals:

	/** \brief Emited when user wants to close Theme view and without saving changes.
	 *
	 */
	void backClicked();	
	
	/** \brief Emited when user wants to change application theme.
	 *
	 */
	void currentThemeChanged();

protected:

	/** \brief Reimplemented from QWidget
	 * 
	 */
	virtual void showEvent( QShowEvent* event );

private slots:

	/** \brief Used to save the themes settings
	 * 
	 * This slot is used when apply button is pressed. 
	 * Data from the Theme list (active theme and all the themes)
	 * are stored in TocSettings.
	 * 
	 * If Theme has been changed it emits currenThemeChanged() signal.
	 */
	void saveThemesSettings();

private: // Methods

private: // Members

	Ui_TocThemesSettingsWidgetClass* ui; 			/// Ui definition header
};

QT_END_NAMESPACE

#endif // TOCTHEMESSETTINGSWIDGET_H
