/** \file TocUserInfoWidget.h
 * \brief Declaration of TocUserInfoWidget class
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef TOCUSERINFOWIDGET_H
#define TOCUSERINFOWIDGET_H

#include "defs.h"

#include <QWidget>


class Ui_TocUserInfoWidgetClass;
class IconProvider;
class TocContactListWidget;
class QListWidgetItem;

QT_BEGIN_NAMESPACE

/** \brief TocUserInfoWidget class
 * 
 */
class TocUserInfoWidget : public QWidget
{
	Q_OBJECT

public:

	/**
	 * Public Constructor
	 */
	TocUserInfoWidget( QListWidgetItem * contactItem, TocContactListWidget * parent, Qt::WindowFlags flags = 0 );

	/**
	 * Destructor
	 */
	~TocUserInfoWidget();

signals:
	
	/** \brief Emited when user commits the changes
	 * 
	 * This signal is emited when user finished editing or creating contacts data. 
	 * 
	 * @param contactItem Newly created item or edited item representing the contact 
	 */
	void contactChanged(QListWidgetItem* contactItem);

	/** \brief Emited when user confirms or discards the changes
	 * 
	 * This signal is emited when user clicked OK or Cancel button. 
	 */
	void finished();

protected:

	/** \brief Reimplemented from QWidget
	 * 
	 */
	virtual void showEvent(QShowEvent* event);
	
private slots:

	/** \brief Used when user finishes editing contacts data
	 * 
	 * When user adds new contact this slot should create a new QListWidgetItem AND
	 * TocContact with the data provided, and emit it with contactChanged( QListWidgetItem* ) signal.
	 * If user edits contact's data it should save the data in an item AND it's
	 * TocContact provided and emit them with contactChanged( QListWidgetItem* ) signal.
	 */
	void okClicked();
	
	/** \brief Used to react on changes to the Gender ComboBox
	 * 
	 * When user changes the combo box selection, this slot should change
	 * an icon (if no custom icon is set by the user).
	 * 
	 * @param index Current changed index
	 */
	void onCurrentIndexChanged( int index );

private: // Members

	Ui_TocUserInfoWidgetClass* 	ui; 					/// Ui definition header
	QListWidgetItem*  			_pContactItem;			/// Item given to the constructor
	QString 					_customPicturePath;		/// Contact's PictureUrl
	QString						_newCustomPicturePath;	/// Contact's PictureUrl
	int 						_currentIndex;			/// Previous index
	IconProvider* 				_pIconProvider;			/// Class that provides contact icons
	TocContactListWidget*		_pContactList;			/// Contact list for which the widget is displayed
};

QT_END_NAMESPACE

#endif // TOCUSERINFOWIDGET_H
