/** \file defs.h
 * \brief Declarations of global typedefs and enumerators.
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef DEFS_H
#define DEFS_H

#include <QVariant>


enum Status {
	Connected = 0,
	Connecting,
	Disconnected
};

Q_DECLARE_METATYPE(Status);

enum Presence {
	Unspecified = 0,
	Offline = 1, //must be 1 to be inline with Tapioca
	Available,
	Away,
	XA,
	Hidden,
	Busy
};

Q_DECLARE_METATYPE(Presence);

enum Reason {
    NoneSpecified = 0,
    Requested,
    NetworkError,
    AuthenticationFailed,
    EncryptionError,
    NameInUse,
    CertificateNotProvided,
    CertificateUntrusted,
    CertificateExpired,
    CertificateNotActivated,
    CertificateHostnameMismatch,
    CertificateFingerPrintMismatch,
    CertificateSigned,
    CertificateOtherError
};

Q_DECLARE_METATYPE(Reason);

enum Gender {
	NotSpecified,
	Male,
	Female
};

Q_DECLARE_METATYPE(Gender);

struct TocContact
{
	QString		uid;
	QString 	name;
	QString		customIconPath;
	int		customIconId;
	Gender		gender;
	Presence	presence;
	QString		description;
};

typedef QList<TocContact*> TocContactList;

Q_DECLARE_METATYPE(TocContactList);

enum MessageDeliveryError {
	Unknown = 0,
	ContactOffline,
	InvalidContact,
	PermissionDenied,
	MessageTooLong,
	UserOffline,
	NotOnContactList,
	CannotCreateChannel,
	NoError
};

Q_DECLARE_METATYPE(MessageDeliveryError);

struct Message
{ 
	QString 				contents;
	uint 					timestamp;
	MessageDeliveryError 	error;
};

Q_DECLARE_METATYPE(Message);

#endif // DEFS_H
