/** \file uidefs.h
 * \brief Declarations of global typedefs and enumerators for UI.
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef UIDEFS_H
#define UIDEFS_H

#define STYLESHEET_ONLINE    	"QFrame { background-color: qlineargradient(x1: 0, y1: 1, x2: 0, y2: 0,"\
"stop: 0 #00aa00, stop: 0.55 #00aa00,"\
"stop: 0.56 #00bb00, stop: 1 #00ff00);}"

#define STYLESHEET_AWAY     	"QFrame { background-color: qlineargradient(x1: 0, y1: 1, x2: 0, y2: 0,"\
"stop: 0 #999900, stop: 0.55 #aaaa00,"\
"stop: 0.56 #bbbb00, stop: 1 #ffff00);}"

#define STYLESHEET_BUSY     	"QFrame { background-color: qlineargradient(x1: 0, y1: 1, x2: 0, y2: 0,"\
"stop: 0 #990000, stop: 0.55 #aa0000,"\
"stop: 0.56 #bb0000, stop: 1 #ff0000);}"

#define STYLESHEET_OFFLINE  	"QFrame { background-color: qlineargradient(x1: 0, y1: 1, x2: 0, y2: 0,"\
"stop: 0 #999, stop: 0.55 #aaa,"\
"stop: 0.56 #bbb, stop: 1 #fff);}"

#define LOGO_BLUE		qRgb(  0, 128, 197)
#define LOGO_LIGHT_BLUE		qRgb(118, 206, 234)
#define LOGO_GREEN		qRgb(153, 204,  51)
#define LOGO_ORANGE		qRgb(255, 153,  51)
#define LOGO_RED		qRgb(230,  40,  88)

enum ViewType {
	Login,
	Contacts,
	Chat,
	UserInfo,
	Settings,
	General,
	Account,
	AccountCreate,
	AccountIntermediate,
	FTU,
	Themes
};

Q_DECLARE_METATYPE(ViewType);

enum TecUserRole {
	DisplayRole,
	DecorationRole,				///An icon merged with status frame
	ContactRole = Qt::UserRole
};

#ifdef QT_NO_DEBUG
  #define emotsPath    	QString("/usr/share/tietoopcom/emoticons/")
#else
  #define emotsPath    	QString("./data/emoticons/")
#endif //QT_NO_DEBUG

#define emotSmile_32x32    	emotsPath + "face-smile32x32.png"
#define emotSad_32x32      	emotsPath + "face-sad32x32.png"
#define emotWink_32x32     	emotsPath + "face-wink32x32.png"
#define emotGrin_32x32     	emotsPath + "face-grin32x32.png"
#define emotSurprise_32x32 	emotsPath + "face-surprise32x32.png"
#define emotPlain_32x32    	emotsPath + "face-plain32x32.png"
#define emotKiss_32x32     	emotsPath + "face-kiss32x32.png"
#define emotAngel_32x32    	emotsPath + "face-angel32x32.png"
#define emotDevil_32x32    	emotsPath + "face-devilish32x32.png"
#define emotMonkey_32x32	emotsPath + "face-monkey32x32.png"
#define emotCrying_32x32	emotsPath + "face-crying32x32.png"
#define emotGlasses_32x32	emotsPath + "face-glasses32x32.png"
#define emotSmileBig_32x32	emotsPath + "face-smile-big32x32.png"

#define emotSmile_24x24    	emotsPath + "face-smile24x24.png"
#define emotSad_24x24      	emotsPath + "face-sad24x24.png"
#define emotWink_24x24     	emotsPath + "face-wink24x24.png"
#define emotGrin_24x24     	emotsPath + "face-grin24x24.png"
#define emotSurprise_24x24 	emotsPath + "face-surprise24x24.png"
#define emotPlain_24x24    	emotsPath + "face-plain24x24.png"
#define emotKiss_24x24     	emotsPath + "face-kiss24x24.png"
#define emotAngel_24x24    	emotsPath + "face-angel24x24.png"
#define emotDevil_24x24    	emotsPath + "face-devilish24x24.png"
#define emotMonkey_24x24	emotsPath + "face-monkey24x24.png"
#define emotCrying_24x24	emotsPath + "face-crying24x24.png"
#define emotGlasses_24x24	emotsPath + "face-glasses24x24.png"
#define emotSmileBig_24x24	emotsPath + "face-smile-big24x24.png"

#endif // UIDEFS_H
