/** \file TocAccountIntermediateWidget.cpp
 * \brief Implementation of TocAccountIntermediateWidget class
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */
 
#include "TocAccountIntermediateWidget"
#include <QPushButton>
#include <QGridLayout>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QFrame>
#include "macros.h"

TocAccountIntermediateWidget::TocAccountIntermediateWidget(QWidget * parent, Qt::WindowFlags flags)
	: QWidget(parent, flags) { 

	setContentsMargins( -10, -10, -10, -10 );
	setObjectName("intermediateWidget");

    QGridLayout* gridLayout = new QGridLayout(this);
    _pIntermediateFrame = new QFrame( this );
    _pIntermediateFrame->setObjectName("intermediateFrame");
    gridLayout->addWidget( _pIntermediateFrame );
    
    QHBoxLayout* mainHorizontalLayout = new QHBoxLayout( _pIntermediateFrame );

    //1st layout - vertical - back button + strech
    QVBoxLayout* vLayout1 = new QVBoxLayout();

    vLayout1->addStretch(1);
    
    _pBackButton = new QPushButton(tr("Back"), this);
    _pBackButton->setObjectName("backButton");
    vLayout1->addWidget(_pBackButton);
    
    mainHorizontalLayout->addLayout(vLayout1);
    
    //2nd layout - vertical - for Create and Edit buttons
    QVBoxLayout* vLayout2 = new QVBoxLayout();

    vLayout2->addStretch(1);
    
    QHBoxLayout* hLayout1 = new QHBoxLayout();

    hLayout1->addStretch(1);
    
    _pCreateButton = new QPushButton(tr("Create\nnew"), this);
    _pCreateButton->setObjectName("createButton");
    hLayout1->addWidget(_pCreateButton);
    
    hLayout1->addStretch(1);    

    _pEditButton = new QPushButton(tr("Edit"), this);
    _pEditButton->setObjectName("editButton");
    hLayout1->addWidget(_pEditButton);
    
    hLayout1->addStretch(1);

    vLayout2->addLayout( hLayout1 );
    vLayout2->addStretch(2);
        
    mainHorizontalLayout->addLayout(vLayout2);
 

    //3rd layout - horizontal - just to add stretch
    QHBoxLayout* hLayout3 = new QHBoxLayout();
    QSpacerItem* spacer = new QSpacerItem(_pBackButton->width(), 0);
    hLayout3->addItem(spacer);
    
    mainHorizontalLayout->addLayout(hLayout3);
        
    
    setupStyles();

    CONNECT(_pBackButton, SIGNAL(clicked()), this, SIGNAL(backClicked()));
    CONNECT(_pEditButton, SIGNAL(clicked()), this, SIGNAL(editClicked()));
    CONNECT(_pCreateButton, SIGNAL(clicked()), this, SIGNAL(createClicked()));
}

TocAccountIntermediateWidget::~TocAccountIntermediateWidget() {

}

void TocAccountIntermediateWidget::setupStyles() {
	setStyleSheet("QPushButton {  }");
	_pCreateButton->setStyleSheet(
		"QPushButton {"
			"font: bold 16px;"
	    	"border-radius: 5px;"
			"min-height: 120px;"
			"min-width: 140px;"
			"max-height: 120px;"
			"max-width: 140px;"
		"}"
	);

	_pEditButton->setStyleSheet(
		"QPushButton {"
			"font: bold 16px;"
	    	"border-radius: 5px;"
			"min-height: 120px;"
			"min-width: 140px;"
			"max-height: 120px;"
			"max-width: 140px;"
		"}"
	);

	_pBackButton->setStyleSheet(
		"QPushButton {"
			"font: bold 16px;"
	    	"border-radius: 5px;"
			"min-height: 80px;"
			"min-width: 80px;"
			"max-height: 80px;"
			"max-width: 80px;"
		"}"
	);
}

void TocAccountIntermediateWidget::enableFTUMode( bool ftu ) {
	_pBackButton->setHidden(ftu);

	if(ftu) {
		_pEditButton->setText(tr("Use\nexisting"));
	} else {
		_pEditButton->setText(tr("Edit"));
	}
}
