/** \file TocEmoticonsDialog.cpp
 * \brief Implementation of TocEmoticonsDialog class
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */
 
#include "ui_TocEmoticonsDialog.h"
#include "TocEmoticonsDialog"
#include "macros.h"
#include "uidefs.h"

// Initialize static objects
TocEmoticonsDialog* TocEmoticonsDialog::_pSelf = 0;

TocEmoticonsDialog* TocEmoticonsDialog::getInstance(QWidget* parent) {

	if (!_pSelf)
		_pSelf = new TocEmoticonsDialog(parent);

	return _pSelf;
}

TocEmoticonsDialog::TocEmoticonsDialog(QWidget *parent)
    : QDialog(parent)
{
	ui = new Ui_TocEmoticonsDialogClass();
	ui->setupUi(this);
	setContentsMargins(-10, -10, -10, -10);
	
	CONNECT(ui->backButton,SIGNAL(clicked()),this,SLOT(reject()));
	CONNECT(ui->emoticonsListWidget,SIGNAL(itemClicked(QListWidgetItem*)),this,SLOT(onEmoticonSelected(QListWidgetItem*)));

	ui->emoticonsListWidget->setFlow(QListView::LeftToRight);
	ui->emoticonsListWidget->setViewMode(QListView::IconMode);
	ui->emoticonsListWidget->setGridSize(QSize(80, 80));
	ui->emoticonsListWidget->setIconSize(QSize(32, 32));
	ui->emoticonsListWidget->setDragEnabled(false);
	ui->emoticonsListWidget->setVerticalScrollMode(QAbstractItemView::ScrollPerItem);
	ui->emoticonsListWidget->setWrapping(true);
	ui->emoticonsListWidget->setWordWrap(true);
	ui->emoticonsListWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
	ui->emoticonsListWidget->setResizeMode(QListView::Adjust);
	
	QFont currentFont(ui->emoticonsListWidget->font());
	currentFont.setPixelSize(14);
	ui->emoticonsListWidget->setFont(currentFont);

	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotSmile_32x32), 
			tr(":)"), 		  ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotSad_32x32),
			tr(":("), 		  ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotPlain_32x32),
			tr(":|"), 		  ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotSurprise_32x32),
			tr(":O"), 		  ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotGrin_32x32),
			tr(":D"), 		  ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotWink_32x32),
			tr(";)"), 		  ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotKiss_32x32),
			tr(":*"), 		  ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotAngel_32x32),
			tr("<angel>"), 	  ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotDevil_32x32),
			tr("<devil>"), 	  ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotMonkey_32x32),
			tr("<monkey>"),	  ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotCrying_32x32),
			tr("<crying>"),   ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotGlasses_32x32),
			tr("<glasses>"),  ui->emoticonsListWidget));
	ui->emoticonsListWidget->addItem(new QListWidgetItem(QIcon(emotSmileBig_32x32),
			tr("<bigsmile>"), ui->emoticonsListWidget));
}

TocEmoticonsDialog::~TocEmoticonsDialog()
{
	delete ui;
}

void TocEmoticonsDialog::onEmoticonSelected(QListWidgetItem* pItem) {
	
	_selectedEmoticonAlias = pItem->text();
	accept();
}

QString TocEmoticonsDialog::getSelectedEmoticonAlias() {
	return _selectedEmoticonAlias;
}
