/** \file TocGeneralSettingsWidget.cpp
 * \brief Implementation of TocGeneralSettingsWidget class
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */
 
#include "TocGeneralSettingsWidget"
#include "ui_TocGeneralSettingsWidget.h"

#include "TocSettings"
#include "macros.h"

#include <QtDebug>
#include <QCommonStyle>

TocGeneralSettingsWidget::TocGeneralSettingsWidget(QWidget * parent, Qt::WindowFlags flags)
	: QWidget(parent, flags) {
	
	  
	setStyle(new QCommonStyle());
	ui = new Ui_TocGeneralSettingsWidgetClass();
	ui->setupUi( this );
	setContentsMargins( -10, -10, -10, -10 );

	TocSettings* pSettings = TocSettings::getInstance();

	/*ui->alphaRadioButton->setAttribute(Qt::WA_TranslucentBackground, true);
	ui->presenceRadioButton->setAttribute(Qt::WA_TranslucentBackground, false);
	ui->dragDropRadioButton->setAttribute(Qt::WA_TranslucentBackground, false);
	ui->acceptRadioButton->setAttribute(Qt::WA_TranslucentBackground, false);
	ui->askRadioButton->setAttribute(Qt::WA_TranslucentBackground, false);
	ui->denyRadioButton->setAttribute(Qt::WA_TranslucentBackground, false);*/
	
	switch( pSettings->sortOrder() ) {
	case Alphabetical:
		ui->alphaRadioButton->setChecked( true );
		break;
	//TODO: To be implemented.
	/*case ByStatus:
		ui->presenceRadioButton->setChecked( true );
		break;
	case None:
		ui->dragDropRadioButton->setChecked( true );
		break;*/
	default:
		ui->alphaRadioButton->setChecked( true );
	}

	switch( pSettings->authorizationRule() ) {
	case AlwaysAccept:
		ui->acceptRadioButton->setChecked( true );
		break;
	//TODO: To be implemented.
	/*case Ask:
		ui->askRadioButton->setChecked( true );
		break;
	case AlwaysDeny:
		ui->denyRadioButton->setChecked( true );
		break;*/
	default:
		//TODO: Change to the commented one when implementation will be done. 
		//ui->askRadioButton->setChecked( true );
		ui->acceptRadioButton->setChecked( true );
	}

	CONNECT(ui->okButton, SIGNAL(clicked()), this, SLOT(saveGeneralSettings()));
	CONNECT(ui->backButton, SIGNAL(clicked()), this, SIGNAL(backClicked()));
	
}

TocGeneralSettingsWidget::~TocGeneralSettingsWidget() {
	delete ui;
}

void TocGeneralSettingsWidget::saveGeneralSettings() {

	TocSettings* pSettings = TocSettings::getInstance();

	if( ui->alphaRadioButton->isChecked() )
		pSettings->setSortOrder( Alphabetical );
	else if( ui->presenceRadioButton->isChecked() )
		pSettings->setSortOrder( ByStatus );
 	else if( ui->dragDropRadioButton->isChecked() )
 		pSettings->setSortOrder( None );

	if( ui->askRadioButton->isChecked() )
		pSettings->setAuthorizationRule( Ask );
	else if( ui->acceptRadioButton->isChecked() )
		pSettings->setAuthorizationRule( AlwaysAccept );
 	else if( ui->denyRadioButton->isChecked() )
 		pSettings->setAuthorizationRule( AlwaysDeny );

	emit finished();
}
