/** \file TocSettingsWidget.cpp
 * \brief Implementation of TocSettingsWidget class
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "TocSettingsWidget"
#include <QSignalMapper>
#include <QGridLayout>
#include <QPushButton>
#include <QSpacerItem>
#include <QFrame>
#include "uidefs.h"
#include "macros.h"

TocSettingsWidget::TocSettingsWidget(QWidget * parent, Qt::WindowFlags flags) :
	QWidget(parent, flags) {

	setContentsMargins(-10, -10, -10, -10);
	setObjectName("settingsWidget");

	QGridLayout* gridLayout = new QGridLayout(this);
	settingsFrame = new QFrame(this);
	settingsFrame->setObjectName("settingsFrame");
	gridLayout->addWidget(settingsFrame);
	QVBoxLayout* vLayout = new QVBoxLayout(settingsFrame);

	vLayout->addStretch(1);

	QHBoxLayout* hLayout = new QHBoxLayout();

	generalButton = new QPushButton(tr("General"), this);
	generalButton->setObjectName("generalButton");
	hLayout->addWidget(generalButton);

	accountButton = new QPushButton(tr("Account"), this);
	accountButton->setObjectName("accountButton");
	hLayout->addWidget(accountButton);

	themesButton = new QPushButton(tr("Themes"), this);
	themesButton->setObjectName("themesButton");
	hLayout->addWidget(themesButton);

	vLayout->addLayout(hLayout);
	vLayout->addStretch(2);

	signalMapper = new QSignalMapper(this);
	signalMapper->setMapping(generalButton, static_cast<int>(General));
	signalMapper->setMapping(accountButton,	static_cast<int>(AccountIntermediate));
	signalMapper->setMapping(themesButton, static_cast<int>(Themes));

	CONNECT(generalButton, SIGNAL(clicked()), signalMapper, SLOT(map()));
	CONNECT(accountButton, SIGNAL(clicked()), signalMapper, SLOT(map()));
	CONNECT(themesButton, SIGNAL(clicked()), signalMapper, SLOT(map()));

	CONNECT(signalMapper, SIGNAL(mapped(int)), this, SIGNAL(triggered(int)));

	setupStyles();
}

TocSettingsWidget::~TocSettingsWidget() {
}

void TocSettingsWidget::setupStyles() {

	generalButton->setStyleSheet("QPushButton {"
		"font: bold 16px;"
		"text-align: bottom;"
		"border-radius: 5px;"
		"background-image: url(:/general.png);"
		"background-repeat:no-repeat;"
		"background-position:center center;"
		"min-height: 120px;"
		"min-width: 140px;"
		"max-height: 120px;"
		"max-width: 140px;"
		"}");

	accountButton->setStyleSheet("QPushButton {"
		"font: bold 16px;"
		"text-align: bottom;"
		"border-radius: 5px;"
		"background-image: url(:/account.png);"
		"background-repeat:no-repeat;"
		"background-position:center center;"
		"min-height: 120px;"
		"min-width: 140px;"
		"max-height: 120px;"
		"max-width: 140px;"
		"}");

	themesButton->setStyleSheet("QPushButton {"
		"font: bold 16px;"
		"text-align: bottom;"
		"border-radius: 5px;"
		"background-image: url(:/themes.png);"
		"background-repeat:no-repeat;"
		"background-position:center center;"
		"min-height: 120px;"
		"min-width: 140px;"
		"max-height: 120px;"
		"max-width: 140px;"
		"}");
}
