/** \file TocThemesSettingsWidget.cpp
 * \brief Implementation of TocThemesSettingsWidget class
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "TocThemesSettingsWidget"
#include "ui_TocThemesSettingsWidget.h"
#include "macros.h"

#include <TocSettings>
#include <QListWidgetItem>
#include <QShowEvent>
#include <QDebug>


TocThemesSettingsWidget::TocThemesSettingsWidget(QWidget *parent, Qt::WindowFlags flags)
	: QWidget(parent, flags) {
	
	ui = new Ui_TocThemesSettingsWidgetClass();
	ui->setupUi(this);
	setContentsMargins(-10, -10, -10, -10);
	
	ui->applyThemeButton->setText(tr("Apply"));
	ui->backThemeButton->setText(tr("Back"));

	//TODO: functionality is not implemented. Add Theme button is hidden. 
	ui->addThemeButton->setVisible(false);
	ui->addThemeButton->setText(tr("Add theme"));

#ifdef QT_NO_DEBUG
  #define ssPath    	QString("/usr/share/tietoopcom/stylesheets/")
#else
  #define ssPath    	QString("./data/stylesheets/")
#endif

	qDebug() << ssPath;

	QListWidgetItem* pItem = new QListWidgetItem("Default theme", ui->themesListWidget);
	pItem->setToolTip(ssPath + "default.qss");

	pItem = new QListWidgetItem("My theme", ui->themesListWidget);
	pItem->setToolTip(ssPath + "my.qss");

	CONNECT(ui->backThemeButton,SIGNAL(clicked()),this,SIGNAL(backClicked()));
	CONNECT(ui->applyThemeButton,SIGNAL(clicked()),this,SLOT(saveThemesSettings()));
}

TocThemesSettingsWidget::~TocThemesSettingsWidget() {
	delete ui;
}

void TocThemesSettingsWidget::showEvent( QShowEvent* event ) {

	TocSettings* pSettings = TocSettings::getInstance();
	for(int i = 0; i < ui->themesListWidget->count(); ++i)
		if(ui->themesListWidget->item(i)->toolTip() == pSettings->currentTheme()) {
			ui->themesListWidget->setCurrentRow(i);
		}
	event->accept();
}

void TocThemesSettingsWidget::saveThemesSettings() {

	TocSettings* pSettings = TocSettings::getInstance();

	QListWidgetItem* pThemesListItem = ui->themesListWidget->currentItem();
	if(!pThemesListItem)
		return;

	QString themeUrl = pThemesListItem->toolTip();
	if(themeUrl == pSettings->currentTheme())
		return;

	pSettings->setCurrentTheme(themeUrl);
	emit currentThemeChanged();
}
