/** \file main.h
 * \brief Implementation of program´s main function
 * 
 * Tieto Open Communicator - Client for the Telepathy communications framework.
 * Copyright (c) 2010, Tieto Corporation
 *
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * 	Redistributions of source code must retain the above copyright notice,
 * 	this list of conditions and the following disclaimer.
 * 	Redistributions in binary form must reproduce the above copyright notice,
 * 	this list of conditions and the following disclaimer in the documentation
 * 	and/or other materials provided with the distribution.
 * 	Neither the name of the Tieto Corporation nor the names of its contributors 
 *	may be used to endorse or promote products derived from this software without
 * 	specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "TocMainWindow"
#include "TocEngine"

#include <QtGui>
#include <QApplication>
#include <QtDBus>

int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
    app.setAttribute(Qt::AA_DontShowIconsInMenus, false);
    
    TocEngine* engine = new TocEngine(&app);
    TocMainWindow w(engine);
    
      if (!QDBusConnection::sessionBus().isConnected()) {
	qWarning("Cannot connect to the D-Bus session bus.");
	exit(1);
    }
 
    if (!QDBusConnection::sessionBus().registerService("org.indt.tietoopcom")) {
	qWarning("%s", qPrintable(QDBusConnection::sessionBus().lastError().message()));
	exit(2);
    }
 
    if (!QDBusConnection::sessionBus().registerObject("/org/indt/tietoopcom", &w,
	QDBusConnection::ExportScriptableSlots)) {
	qWarning("%s", qPrintable(QDBusConnection::sessionBus().lastError().message()));
	exit(3);
    }
    
    w.show();
    bool ret = app.exec();
    delete engine;
    return ret;
}
